@@ -21,8 +21,6 @@ our %SITE_DOM_NAME = (
   'www.jjwxc.net'   => 'jjwxc',
   'tieba.baidu.com' => 'tieba',
 
-  'www.bearead.com'  => 'bearead',
-  'wwwj.bearead.com' => 'bearead',
   'www.ddshu.net'    => 'ddshu',
   'www.kanunu8.com'  => 'kanunu8',
 );
@@ -197,7 +195,7 @@ sub parse_novel {
       { path  => '//div[@id="title"]', },
       { path  => '//div[@class="title"]', },
       { regex => qr#<title>[^<]+?([^,<]+?)全文阅读,#si, },
-      { regex => qr#<title>[^<]+?《([^,<]+?)》#si, },
+      { regex => qr#<title>[^<]*?《([^,<]+?)》#si, },
       { regex => qr#<title>[^<]+?,([^,<]+?)最新章节#si, },
       { path  => '//h1', },
       { path  => '//h2', },
@@ -221,6 +219,7 @@ sub parse_novel {
       { regex => qr#作者：([^<]+?) 发布时间：#s, },
       { regex => qr#content="([^"]+?)最新著作#s, },
       { regex => qr#<title>[^<,]+?最新章节\(([^<,]+?)\),#si, },
+      { regex => qr#<title>[^<,]+?作者：([^<,]+?)_#si, },
       { regex => qr#content="[^"]+?,([^",]+?)作品#s, },
     ],
     sub => $self->can( "tidy_writer_book" ),
@@ -315,7 +314,7 @@ sub guess_item_list {
     $res_arr = $arr if ( $opt{chapter_url_regex}   and $x->{url}   =~ /$opt{chapter_url_regex}/ );
     $res_arr = $arr if ( $opt{chapter_title_regex} and $x->{title} =~ /$opt{chapter_title_regex}/ );
     $res_arr = $arr
-      if ( $x->{title} =~ /$title_regex/ or ( $y and $y->{title} =~ /$title_regex/ ) or ( $z and $z->{title} =~ /$title_regex/ ) );
+      if ( ($x and $x->{title} =~ /$title_regex/) or ( $y and $y->{title} =~ /$title_regex/ ) or ( $z and $z->{title} =~ /$title_regex/ ) );
     $res_arr = $arr if ( ( $x->{url} =~ /$chap_num_regex/ or $z->{url} =~ /$chap_num_regex/ ) and scalar( @$arr ) > 50 );
 
     #$res_arr= $arr if( ($x->{url}=~/\/?\d+$/ or $z->{url}=~/\/?\d+$/) and scalar(@$arr)>50);
@@ -374,6 +373,15 @@ sub parse_novel_item {
   $r = $self->guess_novel_item( $h ) unless ( $r->{content} );
   $r->{$_} ||= $NULL_CHAPTER{$_} for keys( %NULL_CHAPTER );
   $r->{content} = $self->tidy_content( $r->{content} );
+
+  my $next_url = $self->scrape_element_try($h, [ 
+          { path => '//a[@id="next_url"]', extract =>'@href' }, 
+          { path  => '//a[contains(text(),"下一页")]',           extract => '@href' },
+      ]);
+  if($next_url){
+      $r->{next_url} = $next_url;
+  }
+
   return $r;
 }
 
